from typing import Annotated

from asyncreq import request
from fastapi import APIRouter, Header, HTTPException

from src.api.config import API_SUBSCRIPTIONS
from src.api.routes.auth import status as checkAuth
from src.api.schemas.subscriptions import Subscription

router = APIRouter()


@router.post("")
async def create_subscription(
    subscription: Subscription, authorization: Annotated[str | None, Header()] = None
):
    await checkAuth(authorization)
    (response, status, _) = await request(
        f"{API_SUBSCRIPTIONS}", "POST", json=subscription.model_dump()
    )
    if status < 200 or status > 204:
        raise HTTPException(status_code=status, detail=response)
    return response
