import "../../matchMedia.mock";
import "@testing-library/jest-dom";
import { fireEvent, render, screen } from "@testing-library/react";
import { Home } from "./Home";
import { MemoryRouter } from "react-router-dom";

const mockedUseNavigate = jest.fn();

jest.mock("react-router", () => ({
    ...jest.requireActual("react-router"),
    useNavigate: () => mockedUseNavigate,
}));

describe("Home tests", () => {
    test("Renders departure and arrival buttons", () => {
        render(
            <MemoryRouter>
                <Home />
            </MemoryRouter>
        );

        const departureButton = screen.getByText("Departure");
        const arrivalButton = screen.getByText("Arrival");

        expect(departureButton).toBeInTheDocument();
        expect(arrivalButton).toBeInTheDocument();
    });

    test("Clicking departure button navigates to /departure", () => {
        render(
            <MemoryRouter>
                <Home />
            </MemoryRouter>
        );
        const departureButton = screen.getByText("Departure");
        fireEvent.click(departureButton);
        expect(mockedUseNavigate).toHaveBeenCalledWith("/departure");
    });

    test("Clicking arrival button navigates to /arrival", () => {
        render(
            <MemoryRouter>
                <Home />
            </MemoryRouter>
        );
        const arrivalButton = screen.getByText("Arrival");
        fireEvent.click(arrivalButton);
        expect(mockedUseNavigate).toHaveBeenCalledWith("/arrival");
    });
});
